pub async fn commit(
app: &mut App,
connection: Arc<dyn DatabaseConnection>,
) -> Result<(), PersistenceError>Expand description
Awaitable commit that uses the supplied connection for this request.
pub async fn commit(
app: &mut App,
connection: Arc<dyn DatabaseConnection>,
) -> Result<(), PersistenceError>Awaitable commit that uses the supplied connection for this request.